Module server

Module server 

Server registration and status types.

These types are used for Horizon instances to register with Atlas and report their status and availability.

Structs

AdjacentServerInfo
Adjacent server info for the API.
ApiHeartbeatResponse
API heartbeat response.
ApiRegistrationResponse
API response when a server registers.
ApiServerHeartbeat
API heartbeat request.
ApiServerRegistration
Simplified server registration for REST API. This is what Horizon sends to Atlas when registering.
RegistrationResponse
Response from Atlas when a server registers.
ServerHeartbeat
Server heartbeat sent periodically from Horizon to Atlas.
ServerId
Unique identifier for a Horizon server instance. Uses String for JSON API compatibility.
ServerInfo
Basic server information for registration and discovery.
ServerRegistration
Server registration request sent from Horizon to Atlas.
SpawnServerRequest
Request from Atlas to Maestro to spawn a new Horizon instance.
SpawnServerResponse
Response from Maestro after spawning a server.

Enums

ServerCommand
Commands from Atlas to Horizon.
ServerStatus
Current status of a Horizon server instance.